sort_photos: Sort photos by date

Description Usage Arguments Value Examples

View source: R/photos.R

Description

For each photo file, you can move it, copy it, skip it, or delete it.

Usage

1
sort_photos(from, to, subdir = NULL)

Arguments

from

character. Path to directory that contains photo files.

to

character. Path to destination directory to move photo files. Will be created automatically if it doesn't exist.

subdir

character (default: NULL). Optional format to create subdirectory based on date photo was first created. Use the POSIX formatting described in strptime. For example, "%Y %m %B" is the 4-digit year, 2-digit month, and full month name.

Value

Invisibly returns path to destination directory (input argument to) as an fs_path object.

Examples

1
2
3
4
5
## Not run: 

sort_photos("~/Dropbox/Camera Uploads/", "~/Dropbox/family-photos/", subdir = "%Y %m %B")

## End(Not run)

jdblischak/rkindoflife documentation built on Nov. 4, 2019, 2:35 p.m.